The Git module
==============

The git module is designed to allow interaction between the bot and git repositories which are used to store run configurations and results.

.. automodule:: asimov.git
   :members:
   :undoc-members:
   :show-inheritance:
